#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_FIRST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_FIRST_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/interleave_first.hpp>

#endif
